@@ -37,6 +37,8 @@ from .SaveExtrapolatedPopup import SaveExtrapolatedPopup
 from .UI.CorfuncPanel import Ui_CorfuncDialog
 from .util import WIDGETS, safe_float
 
+logger = logging.getLogger(__name__)
+
 
 class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
     """Displays the correlation function analysis of sas data."""
@@ -318,7 +320,7 @@ class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
                 calculator.run()
 
             except CalculationError as e:
-                logging.error("CorfuncCalculator could not complete. " + e.msg)
+                logger.error("CorfuncCalculator could not complete. " + e.msg)
 
             self._calculator = calculator
 
@@ -369,7 +371,7 @@ class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
             self.cmdSaveExtrapolation.setEnabled(True)
 
         except ValueError as e:
-            logging.error(repr(e))
+            logger.error(repr(e))
             self.cmdSave.setEnabled(False)
             self.cmdSaveExtrapolation.setEnabled(False)
             self.set_background_warning()
@@ -639,12 +641,12 @@ class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
         """
 
         if self._calculator is None:
-            logging.error("Save transformed: No calculation present")
+            logger.error("Save transformed: No calculation present")
             return
 
         transformed = self._calculator.transformed
         if transformed is None:
-            logging.error("Save transformed: No transformed data present")
+            logger.error("Save transformed: No transformed data present")
             return
 
         caption = "Save As"
@@ -677,10 +679,10 @@ class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
     def on_save_extrapolation(self):
 
         if self.data is None:
-            logging.error("Save extrapolation: No data present")
+            logger.error("Save extrapolation: No data present")
 
         if self._calculator is None:
-            logging.error("Save extrapolation: No calculation present")
+            logger.error("Save extrapolation: No calculation present")
             return
 
         if self._calculator.extrapolation_function is not None:
@@ -688,7 +690,7 @@ class CorfuncWindow(QtWidgets.QDialog, Ui_CorfuncDialog, Perspective):
             window = SaveExtrapolatedPopup(q, self._calculator.extrapolation_function)
             window.exec_()
         else:
-            logging.error("Save extrapolation: No extrapolation function present")
+            logger.error("Save extrapolation: No extrapolation function present")
 
 
 
