@@ -288,7 +288,7 @@ class InversionWidget(QWidget, Ui_PrInversion):
             if current_calculator.est_bck:
                 self.backgroundInput.setText(format_float(out.background))
             self.computationTimeValue.setText(format_float(out.calc_time))
-            self.chiDofValue.setText(format_float_scientific(out.chi2[0]))
+            self.chiDofValue.setText(format_float_scientific(out.chi2))
             self.oscillationValue.setText(format_float(out.oscillations))
             self.posFractionValue.setText(format_float(out.pos_frac))
             self.sigmaPosFractionValue.setText(format_float(out.pos_err))
