@@ -47,6 +47,9 @@ import sys
 
 import numpy
 
+logger = logging.getLogger(__name__)
+
+
 if 'any' not in dir(__builtins__):
     def any(L):
         for cond in L:
@@ -810,8 +813,8 @@ class View:
                         tempy.append(self.y[i])
                         tempdy.append(self.dy[i])
                 except:
-                    logging.error("check_data_logX: skipping point x %g", self.x[i])
-                    logging.error(sys.exc_info()[1])
+                    logger.error("check_data_logX: skipping point x %g", self.x[i])
+                    logger.error(sys.exc_info()[1])
             self.x = tempx
             self.y = tempy
             self.dx = tempdx
@@ -840,8 +843,8 @@ class View:
                         tempy.append(self.y[i])
                         tempdy.append(self.dy[i])
                 except:
-                    logging.error("check_data_logY: skipping point %g", self.y[i])
-                    logging.error(sys.exc_info()[1])
+                    logger.error("check_data_logY: skipping point %g", self.y[i])
+                    logger.error(sys.exc_info()[1])
 
             self.x = tempx
             self.y = tempy
