@@ -2,9 +2,11 @@
 """
 Allows users to modify the box slicer parameters.
 """
+
 import functools
 import logging
 import os
+from enum import Enum
 
 from PySide6 import QtCore, QtGui, QtWidgets
 
@@ -22,19 +24,31 @@ from sas.qtgui.Plotting.Slicers.WedgeSlicer import WedgeInteractorPhi, WedgeInte
 # Local UI
 from sas.qtgui.Plotting.UI.SlicerParametersUI import Ui_SlicerParametersUI
 
+logger = logging.getLogger(__name__)
+
+
+class FittingType(Enum):
+    NO_FITTING: int = 0
+    FITTING_SINGLE: int = 1
+    FITTING_BATCH: int = 2
+    INVERSION_SINGLE: int = 3
+    INVERSION_BATCH: int = 4
+
+
+FITTING_TYPES: set[int] = {FittingType.FITTING_SINGLE, FittingType.FITTING_BATCH}  # 1, 2
+BATCH_TYPES: set[int] = {FittingType.FITTING_BATCH, FittingType.INVERSION_BATCH}  # 2, 4
+INVERSION_TYPES: set[int] = {FittingType.INVERSION_SINGLE, FittingType.INVERSION_BATCH}  # 3, 4
+
 
 class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
     """
     Interaction between the QTableView and the underlying model,
     passed from a slicer instance.
     """
+
     closeWidgetSignal = QtCore.Signal()
 
-    def __init__(self, parent=None,
-                 model=None,
-                 active_plots=None,
-                 validate_method=None,
-                 communicator=None):
+    def __init__(self, parent=None, model=None, active_plots=None, validate_method=None, communicator=None):
         super(SlicerParameters, self).__init__(parent.manager)
 
         self.setupUi(self)
@@ -53,13 +67,15 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         self.cmdApply.setEnabled(False)
 
         # Mapping combobox index -> slicer module
-        self.callbacks = {0: None,
-                          1: SectorInteractor,
-                          2: AnnulusInteractor,
-                          3: BoxInteractorX,
-                          4: BoxInteractorY,
-                          5: WedgeInteractorQ,
-                          6: WedgeInteractorPhi}
+        self.callbacks = {
+            0: None,
+            1: SectorInteractor,
+            2: AnnulusInteractor,
+            3: BoxInteractorX,
+            4: BoxInteractorY,
+            5: WedgeInteractorQ,
+            6: WedgeInteractorPhi,
+        }
 
         # Define a proxy model so cell enablement can be finegrained.
         self.proxy = ProxyModel(self)
@@ -100,8 +116,7 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         # Disable row number display
         self.lstParams.verticalHeader().setVisible(False)
         self.lstParams.setAlternatingRowColors(True)
-        self.lstParams.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding,
-                                     QtWidgets.QSizePolicy.Expanding)
+        self.lstParams.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Expanding)
 
         # Header properties for nicer display
         header = self.lstParams.horizontalHeader()
@@ -109,8 +124,7 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         header.setStretchLastSection(True)
 
     def updatePlotList(self):
-        '''
-        '''
+        """ """
         self.active_plots = self.parent.getActivePlots()
         self.setPlotsList()
 
@@ -184,14 +198,14 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         self.lstPlots.itemChanged.connect(lambda: self.cmdApply.setEnabled(True))
 
     def onFocus(self, row, column):
-        """ Set the focus on the cell (row, column) """
+        """Set the focus on the cell (row, column)"""
         selection_model = self.lstParams.selectionModel()
         selection_model.select(self.model.index(row, column), QtGui.QItemSelectionModel.Select)
         self.lstParams.setSelectionModel(selection_model)
         self.lstParams.setCurrentIndex(self.model.index(row, column))
 
     def onSlicerChanged(self, index):
-        """ change the parameters based on the slicer chosen """
+        """change the parameters based on the slicer chosen"""
         if index == 0:  # No interactor
             self.parent.onClearSlicer()
             self.setModel(None)
@@ -216,7 +230,7 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         Open save file location dialog
         """
         parent = self
-        caption = 'Save files to:'
+        caption = "Save files to:"
         options = QtWidgets.QFileDialog.ShowDirsOnly
         directory = self.save_location
         folder = QtWidgets.QFileDialog.getExistingDirectory(parent, caption, directory, options)
@@ -305,15 +319,14 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         Prepares full, unique path for a 1D plot
         """
         # Extend filename with the requested string
-        filename = data.name if self.txtExtension.text() == ""\
-            else data.name + "_" + str(self.txtExtension.text())
+        filename = data.name if self.txtExtension.text() == "" else data.name + "_" + str(self.txtExtension.text())
         extension = self.cbSaveExt.currentText()
         filename_ext = filename + extension
 
         # Assure filename uniqueness
         dst_filename = GuiUtils.findNextFilename(filename_ext, self.save_location)
         if not dst_filename:
-            logging.error("Could not find appropriate filename for " + filename_ext)
+            logger.error("Could not find appropriate filename for " + filename_ext)
             return
         filepath = os.path.join(self.save_location, dst_filename)
         return filepath
@@ -324,12 +337,12 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         """
         # Choose serializer based on requested extension
         extension = self.cbSaveExt.currentText()
-        if 'txt' in extension:
+        if "txt" in extension:
             GuiUtils.onTXTSave(data, filepath)
-        elif 'xml' in extension:
+        elif "xml" in extension:
             loader = Loader()
             loader.save(filepath, data, ".xml")
-        elif 'h5' in extension:
+        elif "h5" in extension:
             nxcansaswriter = NXcanSASWriter()
             nxcansaswriter.write([data], filepath)
         else:
@@ -360,17 +373,16 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         # Send to fitting, if needed
         # We can get away with directly querying the UI, since this is the only
         # place we need that state.
-        fitting_requested = self.cbFitOptions.currentIndex()
+        fitting_requested = FittingType(self.cbFitOptions.currentIndex())
         self.sendToFit(items_for_fit, fitting_requested)
 
     def setModel(self, model):
-        """ Model setter """
+        """Model setter"""
         # check if parent slicer changed
         current_slicer = type(self.parent.slicer)
         for index in self.callbacks:
             # must use type() for None or just imported type for ! None
-            if type(self.callbacks[index]) == current_slicer or \
-               self.callbacks[index] == current_slicer:
+            if type(self.callbacks[index]) == current_slicer or self.callbacks[index] == current_slicer:
                 if index != self.cbSlicer.currentIndex():
                     # parameters already updated, no need to notify
                     # combobox listeners
@@ -383,22 +395,23 @@ class SlicerParameters(QtWidgets.QDialog, Ui_SlicerParametersUI):
         if model is not None:
             self.model.itemChanged.connect(self.onParamChange)
 
-    def check_perspective_and_set_data(self,fitting_requested, perspective_name, items_for_fit):        
-        isBatch = fitting_requested in (2, 4)
-        self.parent.manager.parent.loadedPerspectives[perspective_name].setData(data_item=items_for_fit,is_batch=isBatch)
+    def check_perspective_and_set_data(self, fitting_requested, perspective_name, items_for_fit):
+        isBatch = fitting_requested in BATCH_TYPES
+        self.parent.manager.parent.loadedPerspectives[perspective_name].setData(
+            data_item=items_for_fit, is_batch=isBatch
+        )
 
     def sendToFit(self, items_for_fit, fitting_requested):
         """
         Send `items_for_fit` to the Fit perspective, in either single fit or batch mode
         """
 
-        if fitting_requested in (1, 2):
-            self.check_perspective_and_set_data(fitting_requested, 'Fitting', items_for_fit)
-        elif fitting_requested in (3, 4):
-            self.check_perspective_and_set_data(fitting_requested, 'Inversion', items_for_fit)
+        if fitting_requested in FITTING_TYPES:
+            self.check_perspective_and_set_data(fitting_requested, "Fitting", items_for_fit)
+        elif fitting_requested in INVERSION_TYPES:
+            self.check_perspective_and_set_data(fitting_requested, "Inversion", items_for_fit)
         else:
             return
-    
 
     def keyPressEvent(self, event):
         """
@@ -429,23 +442,24 @@ class ProxyModel(QtCore.QIdentityProxyModel):
     """
     Trivial proxy model with custom column edit flag
     """
+
     def __init__(self, parent=None):
         super(ProxyModel, self).__init__(parent)
         self._columns = set()
 
     def columnReadOnly(self, column):
-        '''Returns True if column is read only, false otherwise'''
+        """Returns True if column is read only, false otherwise"""
         return column in self._columns
 
     def setColumnReadOnly(self, column, readonly=True):
-        '''Add/removes a column from the readonly list'''
+        """Add/removes a column from the readonly list"""
         if readonly:
             self._columns.add(column)
         else:
             self._columns.discard(column)
 
     def flags(self, index):
-        '''Sets column flags'''
+        """Sets column flags"""
         flags = super(ProxyModel, self).flags(index)
         if self.columnReadOnly(index.column()):
             flags &= ~QtCore.Qt.ItemIsEditable
