@@ -7,6 +7,8 @@ from sas.qtgui.Plotting.PlotterData import Data1D
 from sas.qtgui.Plotting.SlicerModel import SlicerModel
 from sas.qtgui.Plotting.Slicers.BaseInteractor import BaseInteractor
 
+logger = logging.getLogger(__name__)
+
 
 class BoxInteractor(BaseInteractor, SlicerModel):
     """
@@ -232,7 +234,7 @@ class BoxInteractor(BaseInteractor, SlicerModel):
         try:
             boxavg = box(self.data)
         except ValueError as ve:
-            logging.warning(str(ve))
+            logger.warning(str(ve))
             self.restore(ev=None)
             self.update()
             self.draw()
@@ -285,6 +287,7 @@ class BoxInteractor(BaseInteractor, SlicerModel):
         if self._item.parent() is not None:
             item = self._item.parent()
         GuiUtils.updateModelItemWithPlot(item, new_plot, new_plot.id)
+        self.base.manager.communicator.plotUpdateSignal.emit([new_plot])
         self.base.manager.communicator.forcePlotDisplaySignal.emit([item, new_plot])
 
         if self.update_model:
@@ -381,16 +384,18 @@ class BoxInteractor(BaseInteractor, SlicerModel):
     def validate(self, param_name, param_value):
         """
         Validate input from user.
-        Values get checked at apply time.
-        * nbins cannot be zero or samller
-        * The full ROI should stay within the data. thus center_x and center_y
+
+        Values get checked at apply time:
+
+        * ``nbins`` cannot be zero or smaller
+        * The full ROI should stay within the data. Thus ``center_x`` and ``center_y``
           are restricted such that the center +/- width (or height) cannot be
-          greate or smaller than data max/min.
+          greater or smaller than data max/min.
         * The width/height should not be set so small as to leave no data in
           the ROI. Here we only make sure that the width/height is not zero
           as done when dragging the vertical or horizontal lines. We let the
-          call to _post_data capture the ValueError of no points in ROI
-          raised by manipulations.py, log the message and negate the entry
+          call to ``_post_data`` capture the ``ValueError`` of no points in ROI
+          raised by ``manipulations.py``, log the message and negate the entry
           at that point.
         """
         isValid = True
@@ -400,34 +405,31 @@ class BoxInteractor(BaseInteractor, SlicerModel):
             # there remains no points to average in the ROI. We leave this
             # second check to manipulations.py
             if param_value <= 0:
-                logging.warning("The box width is too small. Please adjust.")
+                logger.warning("The box width is too small. Please adjust.")
                 isValid = False
         elif param_name =='half_height':
             # Can't be negative for sure. Also, it should not be so small that
             # there remains no points to average in the ROI. We leave this
             # second check to manipulations.py
             if param_value <= 0:
-                logging.warning("The box height is too small. Please adjust.")
+                logger.warning("The box height is too small. Please adjust.")
                 isValid = False
         elif param_name == 'nbins':
             # Can't be negative or 0
             if param_value < 1:
-                logging.warning("Number of bins cannot be less than or equal"\
-                                 "to 0. Please adjust.")
+                logger.warning("Number of bins cannot be less than or equal to 0. Please adjust.")
                 isValid = False
         elif param_name == 'center_x':
             # Keep the full ROI box within the data (only moving x here)
             if (param_value + self.half_width) >= self.data.xmax or \
                     (param_value- self.half_width) <= self.data.xmin:
-                logging.warning("The ROI must be fully contained within the"\
-                                "2D data. Please adjust")
+                logger.warning("The ROI must be fully contained within the 2D data. Please adjust")
                 isValid = False
         elif param_name == 'center_y':
             # Keep the full ROI box within the data (only moving y here)
             if (param_value + self.half_height) >= self.data.ymax or \
                     (param_value - self.half_height) <= self.data.ymin:
-                logging.warning("The ROI must be fully contained within the"\
-                                "2D data. Please adjust")
+                logger.warning("The ROI must be fully contained within the 2D data. Please adjust")
                 isValid = False
         return isValid
 
@@ -634,7 +636,7 @@ class VerticalDoubleLine(BaseInteractor):
         :param x2: new minimum value of x coordinates
         :param y1: new maximum value of y coordinates
         :param y2: new minimum value of y coordinates
-        :param half_ width: is the half width of the new rectangle
+        :param half_width: is the half width of the new rectangle
         :param half_height: is the half height of the new rectangle
         :param center: provided x, y  coordinates of the center point
         """
@@ -729,7 +731,7 @@ class VerticalDoubleLine(BaseInteractor):
         else:
             if self.valid_move:
                 self.valid_move = False
-                logging.warning("the ROI cannot be negative")
+                logger.warning("the ROI cannot be negative")
 
     def setCursor(self, x, y):
         """
@@ -911,7 +913,7 @@ class HorizontalDoubleLine(BaseInteractor):
         else:
             if self.valid_move:
                 self.valid_move = False
-                logging.warning("the ROI cannot be negative")
+                logger.warning("the ROI cannot be negative")
 
     def setCursor(self, x, y):
         """
