@@ -15,9 +15,10 @@ from sas.qtgui.Utilities.CustomGUI.CodeEditor import QCodeEditor
 from sas.qtgui.Utilities.ModelEditors.TabbedEditor.ModelEditor import ModelEditor
 from sas.qtgui.Utilities.ModelEditors.TabbedEditor.PluginDefinition import PluginDefinition
 from sas.qtgui.Utilities.ModelEditors.TabbedEditor.UI.TabbedModelEditor import Ui_TabbedModelEditor
-from sas.sascalc.fit import models
 from sas.system.user import MAIN_DOC_SRC, find_plugins_dir
 
+logger = logging.getLogger(__name__)
+
 
 class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
     """
@@ -174,7 +175,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
 
         # Load the file
         if not filename:
-            logging.info("No data file chosen.")
+            logger.info("No data file chosen.")
             return
 
         # remove c-plugin tab, if present.
@@ -350,7 +351,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
             return
 
         # check if file exists
-        plugin_location = models.find_plugins_dir()
+        plugin_location = find_plugins_dir()
 
         # Generate the full path of the python path for the model and ensure the extension is .py
         full_path = Path(plugin_location) / filename
@@ -408,7 +409,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
         # Notify the user
         msg = "Custom model " + filename + " successfully created."
         self.parent.communicate.statusBarUpdateSignal.emit(msg)
-        logging.info(msg)
+        logger.info(msg)
 
     def createOrUpdateTab(self, filename: str | Path, widget: QtWidgets.QWidget):
         """Check if the widget is already included in the list of tabs. Add it, if it isn't already present
@@ -455,13 +456,13 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
 
         except Exception as ex:
             msg = "Error building model: " + str(ex)
-            logging.error(msg)
+            logger.error(msg)
             # print four last lines of the stack trace
             # this will point out the exact line failing
             all_lines = traceback.format_exc().split("\n")
             last_lines = all_lines[-4:]
             traceback_to_show = "\n".join(last_lines)
-            logging.error(traceback_to_show)
+            logger.error(traceback_to_show)
 
             # Set the status bar message
             # GuiUtils.Communicate.statusBarUpdateSignal.emit("Model check failed")
@@ -501,7 +502,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
         filename = self.filename_py if w.is_python else self.filename_c
         # make sure we have the file handle ready
         if not filename:
-            logging.error("No file name was provided for your plugin model. No file was written.")
+            logger.error("No file name was provided for your plugin model. No file was written.")
             return
 
         # Retrieve model string
@@ -510,7 +511,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
         self.writeFile(filename, model_str)
 
         # Get model filepath
-        plugin_location = models.find_plugins_dir()
+        plugin_location = find_plugins_dir()
         full_path = Path(plugin_location) / filename
 
         error_line = self.findFirstError(full_path.with_suffix(".py"))
@@ -549,7 +550,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
         # notify the user
         msg = f"{str(filename)} successfully saved."
         self.parent.communicate.statusBarUpdateSignal.emit(msg)
-        logging.info(msg)
+        logger.info(msg)
         if self.is_documentation:
             self.regenerateDocumentation()
 
@@ -948,7 +949,7 @@ class TabbedModelEditor(QtWidgets.QDialog, Ui_TabbedModelEditor):
         def visit_FunctionDef(self, node):
             """
             Extract the source code of the function with the given name.
-            NOTE: Do NOT change the name of this method-- visit_ is a prefix that ast.NodeVisitor uses
+            NOTE: Do NOT change the name of this method; ``visit_`` is a prefix that ast.NodeVisitor uses
             """
             if node.name == self.function_name:
                 body = node.body
