@@ -10,39 +10,37 @@ def get_qstar(inv, extrapolation=None):
     """
     return inv.get_qstar(extrapolation)
 
+
 def get_qstar_with_error(inv, extrapolation=None):
     """
     Get invariant value with uncertainty
     """
     return inv.get_qstar_with_error(extrapolation)
 
+
 def get_volume_fraction(inv, contrast, extrapolation=None):
     """
     Get volume fraction
     """
     return inv.get_volume_fraction(contrast, extrapolation)
 
+
 def get_volume_fraction_with_error(inv, contrast, extrapolation=None):
     """
     Get volume fraction with uncertainty
     """
-    return inv.get_volume_fraction_with_error(contrast,
-                                                    extrapolation)
+    return inv.get_volume_fraction_with_error(contrast, extrapolation)
+
 
 def get_surface(inv, contrast, porod_const, extrapolation=None):
     """
     Get surface with uncertainty
     """
-    return inv.get_surface(contrast=contrast,
-                                      porod_const=porod_const,
-                                      extrapolation=extrapolation)
+    return inv.get_surface(contrast=contrast, porod_const=porod_const, extrapolation=extrapolation)
 
-def get_surface_with_error(inv, contrast,
-                           porod_const, extrapolation=None):
+
+def get_surface_with_error(inv, contrast, porod_const, extrapolation=None):
     """
     Get surface with uncertainty
     """
-    return inv.get_surface_with_error(contrast=contrast,
-                                      porod_const=porod_const,
-                                      extrapolation=extrapolation)
-
+    return inv.get_surface_with_error(contrast=contrast, porod_const=porod_const, extrapolation=extrapolation)
